<?php

use App\Http\Controllers\Admin\AffiliateUsers\AffiliateUsersController;
use App\Http\Controllers\Admin\AffiliateUsers\PromoGroup\PromoGroupController;
use App\Http\Controllers\Admin\Settings\SettingController;
use App\Http\Controllers\Customers\CustomerController;
use App\Http\Controllers\Dashboard\DashboardController;
use App\Http\Controllers\Front\FrontController;
use App\Http\Controllers\Settings\Profile\ProfileController;
use App\Http\Controllers\Transaction\TransactionController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
 */
/*************************************
 *         AUTH ROUTES
 ************************************/

Auth::routes(['register' => false]);

/*************************************
 *      END AUTH ROUTES
 ************************************/

/*************************************
 *         FRONT ROUTES
 ************************************/

//  App Entrance route

Route::get('/',[DashboardController::class,'app_root_route_callback']);

//  App Entrance Route

Route::get('payment/{key}', [FrontController::class, 'index_callback'])->name('front.index');

//  STORE PAYMENT INFO

Route::post('/payment-info/store', [FrontController::class, 'store_payment_info_callback'])->name('paymentinfo.store');

// END STORE PAYMENT INFO

/*************************************
 *      END FRONT ROUTES
 ************************************/

 
/*************************************
 *         ADMIN ROUTES
 ************************************/

Route::group(['prefix' => 'admin', 'middleware' => ['auth', 'isAdmin']], function () {

//------- Affiliate Users --------

    Route::get('/affiliate-user', [AffiliateUsersController::class, 'affiliate_user_index_callback'])->name('affiliate_user.index');
    Route::post('/affiliate-user/save', [AffiliateUsersController::class, 'affiliate_user_save'])->name('affiliate_user.save');
    Route::delete('/affiliate-user/delete', [AffiliateUsersController::class, 'affiliate_user_delete'])->name('affiliate_user.delete');
    Route::get('/affiliate-user/{user}/edit', [AffiliateUsersController::class, 'affiliate_user_edit'])->name('affiliate_user.edit');
    Route::put('/affiliate-user/update', [AffiliateUsersController::class, 'affiliate_user_update'])->name('affiliate_user.update');

//----- Promo Group  -------------

    Route::get('/affiliate-user/promo-group', [PromoGroupController::class, 'promo_group_callback'])->name('affiliate_user.promo_group.index');
    Route::post('/affiliate-user/promo-group/save', [PromoGroupController::class, 'promo_group_save'])->name('affiliate_user.promo_group.save');
    Route::get('/affiliate-user/promo-group/{promo_group}/edit', [PromoGroupController::class, 'promo_group_edit'])->name('affiliate_user.promo_group.edit');
    Route::put('/affiliate-user/promo-group/update', [PromoGroupController::class, 'promo_group_update'])->name('affiliate_user.promo_group.update');
    Route::delete('/affiliate-user/promo-group/delete', [PromoGroupController::class, 'promo_group_delete'])->name('affiliate_user.promo_group.delete');
//----- END Promo Group  ----------

//------- END Affiliate Users -----

//--------- Payment Settings ------

    Route::get('/settings', [SettingController::class, 'show_settings_callback'])->name('show.settings');
    Route::put('/settings/store', [SettingController::class, 'store_settings_callback'])->name('store.settings');

//------ END Payment Settings -----

});

/*************************************
 *        END ADMIN ROUTES
 ************************************/

/*************************************
 *       ADMIN && USER ROUTES
 ************************************/

 Route::post('/create_transaction', [FrontController::class, 'create_transaction'])->name('transaction.create_transaction');
 Route::post('/update_transaction', [FrontController::class, 'update_transaction'])->name('transaction.update_transaction');


Route::group(['middleware' => 'auth'], function () {

//------- Dashboard ------------------

    Route::get('/dashboard', [DashboardController::class, 'index'])->name('admin.user.dashboard');

//------- END Dashboard --------------

//------- Transaction ----------------

    Route::get('/transaction/all', [TransactionController::class, 'all_transactions_callback'])->name('transaction.all');
    Route::get('/transaction/failed', [TransactionController::class, 'failed_transactions_callback'])->name('transaction.failed');
    
    Route::post('/transaction/refund', [TransactionController::class, 'refund_transaction_callback'])->name('transaction.refund');
    
    Route::post('/transaction/export', [TransactionController::class, 'export_transaction_callback'])->name('transaction.export');
    
    Route::get('/transaction/refund', [TransactionController::class, 'refund_transaction_detail_callback'])->name('transaction.refund.detail');

//------- END Transaction ------------

//------- Profile --------------------

    Route::get('/settings/profile', [ProfileController::class, 'setting_profile_callback'])->name('settings.profile');
    Route::put('/settings/update-profile', [ProfileController::class, 'setting_profile_update_callback'])->name('settings.profile.update');

//------- End Profile ----------------

//------- Customers ------------------

    Route::get('customers', [CustomerController::class, 'index'])->name('customers.index');

//------- END Customers --------------

//------------------- Transaction Detail Ajax Request -----------------------

    Route::post('/transaction-detail', [TransactionController::class, 'transaction_detail_callback'])->name('transction.detail');

//------------------- END Transaction Detail Ajax Request -------------------

});

/*************************************
 *     END ADMIN && USER ROUTES
 ************************************/
